@@ -497,7 +497,14 @@ function upload_attachment($form_name, $forum_id, $local = false, $local_storage
 	{
 		if ($free_space <= $file->get('filesize'))
 		{
-			$filedata['error'][] = $user->lang['ATTACH_QUOTA_REACHED'];
+			if ($auth->acl_get('a_'))
+			{
+				$filedata['error'][] = $user->lang['ATTACH_DISK_FULL'];
+			}
+			else
+			{
+				$filedata['error'][] = $user->lang['ATTACH_QUOTA_REACHED'];
+			}
 			$filedata['post_attach'] = false;
 
 			$file->remove();
@@ -1180,36 +1187,32 @@ function user_notification($mode, $subject, $topic_title, $forum_name, $forum_id
 	$topic_title = ($topic_notification) ? $topic_title : $subject;
 	$topic_title = censor_text($topic_title);
 
-	// Get banned User ID's
-	$sql = 'SELECT ban_userid
-		FROM ' . BANLIST_TABLE . '
-		WHERE ban_userid <> 0
-			AND ban_exclude <> 1';
-	$result = $db->sql_query($sql);
-
-	$sql_ignore_users = ANONYMOUS . ', ' . $user->data['user_id'];
-	while ($row = $db->sql_fetchrow($result))
+	// Exclude guests, current user and banned users from notifications
+	if (!function_exists('phpbb_get_banned_user_ids'))
 	{
-		$sql_ignore_users .= ', ' . (int) $row['ban_userid'];
+		include($phpbb_root_path . 'includes/functions_user.' . $phpEx);
 	}
-	$db->sql_freeresult($result);
+	$sql_ignore_users = phpbb_get_banned_user_ids();
+	$sql_ignore_users[ANONYMOUS] = ANONYMOUS;
+	$sql_ignore_users[$user->data['user_id']] = $user->data['user_id'];
 
 	$notify_rows = array();
 
 	// -- get forum_userids	|| topic_userids
 	$sql = 'SELECT u.user_id, u.username, u.user_email, u.user_lang, u.user_notify_type, u.user_jabber
 		FROM ' . (($topic_notification) ? TOPICS_WATCH_TABLE : FORUMS_WATCH_TABLE) . ' w, ' . USERS_TABLE . ' u
-		WHERE w.' . (($topic_notification) ? 'topic_id' : 'forum_id') . ' = ' . (($topic_notification) ? $topic_id : $forum_id) . "
-			AND w.user_id NOT IN ($sql_ignore_users)
-			AND w.notify_status = " . NOTIFY_YES . '
+		WHERE w.' . (($topic_notification) ? 'topic_id' : 'forum_id') . ' = ' . (($topic_notification) ? $topic_id : $forum_id) . '
+			AND ' . $db->sql_in_set('w.user_id', $sql_ignore_users, true) . '
+			AND w.notify_status = ' . NOTIFY_YES . '
 			AND u.user_type IN (' . USER_NORMAL . ', ' . USER_FOUNDER . ')
 			AND u.user_id = w.user_id';
 	$result = $db->sql_query($sql);
 
 	while ($row = $db->sql_fetchrow($result))
 	{
-		$notify_rows[$row['user_id']] = array(
-			'user_id'		=> $row['user_id'],
+		$notify_user_id = (int) $row['user_id'];
+		$notify_rows[$notify_user_id] = array(
+			'user_id'		=> $notify_user_id,
 			'username'		=> $row['username'],
 			'user_email'	=> $row['user_email'],
 			'user_jabber'	=> $row['user_jabber'],
@@ -1219,30 +1222,29 @@ function user_notification($mode, $subject, $topic_title, $forum_name, $forum_id
 			'method'		=> $row['user_notify_type'],
 			'allowed'		=> false
 		);
+
+		// Add users who have been already notified to ignore list
+		$sql_ignore_users[$notify_user_id] = $notify_user_id;
 	}
 	$db->sql_freeresult($result);
 
 	// forum notification is sent to those not already receiving topic notifications
 	if ($topic_notification)
 	{
-		if (sizeof($notify_rows))
-		{
-			$sql_ignore_users .= ', ' . implode(', ', array_keys($notify_rows));
-		}
-
 		$sql = 'SELECT u.user_id, u.username, u.user_email, u.user_lang, u.user_notify_type, u.user_jabber
 			FROM ' . FORUMS_WATCH_TABLE . ' fw, ' . USERS_TABLE . " u
 			WHERE fw.forum_id = $forum_id
-				AND fw.user_id NOT IN ($sql_ignore_users)
-				AND fw.notify_status = " . NOTIFY_YES . '
+				AND " . $db->sql_in_set('fw.user_id', $sql_ignore_users, true) . '
+				AND fw.notify_status = ' . NOTIFY_YES . '
 				AND u.user_type IN (' . USER_NORMAL . ', ' . USER_FOUNDER . ')
 				AND u.user_id = fw.user_id';
 		$result = $db->sql_query($sql);
 
 		while ($row = $db->sql_fetchrow($result))
 		{
-			$notify_rows[$row['user_id']] = array(
-				'user_id'		=> $row['user_id'],
+			$notify_user_id = (int) $row['user_id'];
+			$notify_rows[$notify_user_id] = array(
+				'user_id'		=> $notify_user_id,
 				'username'		=> $row['username'],
 				'user_email'	=> $row['user_email'],
 				'user_jabber'	=> $row['user_jabber'],
@@ -1273,7 +1275,6 @@ function user_notification($mode, $subject, $topic_title, $forum_name, $forum_id
 		}
 	}
 
-
 	// Now, we have to do a little step before really sending, we need to distinguish our users a little bit. ;)
 	$msg_users = $delete_ids = $update_notification = array();
 	foreach ($notify_rows as $user_id => $row)
@@ -1286,6 +1287,20 @@ function user_notification($mode, $subject, $topic_title, $forum_name, $forum_id
 		{
 			$msg_users[] = $row;
 			$update_notification[$row['notify_type']][] = $row['user_id'];
+
+			/*
+			* We also update the forums watch table for this user when we are
+			* sending out a topic notification to prevent sending out another
+			* notification in case this user is also subscribed to the forum
+			* this topic was posted in.
+			* Since an UPDATE query is used, this has no effect on users only
+			* subscribed to the topic (i.e. no row is created) and should not
+			* be a performance issue.
+			*/
+			if ($row['notify_type'] === 'topic')
+			{
+				$update_notification['forum'][] = $row['user_id'];
+			}
 		}
 	}
 	unset($notify_rows);
